@@ -44,8 +44,8 @@ def add_organization(
 
         )
     """
-    organization_input = AddOrganizationInput(name=name, description=description)
-    if organization_input.name is not None:
+    if name is not None:
+        organization_input = AddOrganizationInput(name=name, description=description)
         result = addOrganization.execute(client, input=organization_input)
         return organization(name=result.name, id=result.id, description=result.description)
     else:
